#include "copytodialog.h"
#include "ui_copytodialog.h"

copyToDialog::copyToDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::copyToDialog)
{
    ui->setupUi(this);
    ui->copyToDialogBtnBox->addButton("OK", QDialogButtonBox::YesRole);
    ui->copyToDialogBtnBox->addButton("Cancel", QDialogButtonBox::NoRole);
}

copyToDialog::~copyToDialog()
{
    delete ui;
}
